"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.RepeatMode = exports.ResizeMode = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const VideoView = (0, react_native_1.requireNativeComponent)('VideoView');
const VideoPlayer = (props) => {
    return react_1.default.createElement(VideoView, Object.assign({}, props));
};
var RepeatMode;
(function (RepeatMode) {
    RepeatMode[RepeatMode["REPEAT_MODE_OFF"] = 0] = "REPEAT_MODE_OFF";
    /**
     * Repeats the currently playing {@link MediaItem} infinitely during ongoing playback. "Previous"
     * and "Next" actions behave as they do in {@link #REPEAT_MODE_OFF}, moving to the previous and
     * next {@link MediaItem} respectively, and doing nothing when there is no previous or next {@link
     * MediaItem} to move to.
     */
    RepeatMode[RepeatMode["REPEAT_MODE_ONE"] = 1] = "REPEAT_MODE_ONE";
    /**
     * Repeats the entire timeline infinitely. "Previous" and "Next" actions behave as they do in
     * {@link #REPEAT_MODE_OFF}, but with looping at the ends so that "Previous" when playing the
     * first {@link MediaItem} will move to the last {@link MediaItem}, and "Next" when playing the
     * last {@link MediaItem} will move to the first {@link MediaItem}.
     */
    RepeatMode[RepeatMode["REPEAT_MODE_ALL"] = 2] = "REPEAT_MODE_ALL";
})(RepeatMode || (RepeatMode = {}));
exports.RepeatMode = RepeatMode;
var ResizeMode;
(function (ResizeMode) {
    /**
     * Either the width or height is decreased to obtain the desired aspect ratio.
     */
    ResizeMode[ResizeMode["RESIZE_MODE_FIT"] = 0] = "RESIZE_MODE_FIT";
    /**
     * The width is fixed and the height is increased or decreased to obtain the desired aspect ratio.
     */
    ResizeMode[ResizeMode["RESIZE_MODE_FIXED_WIDTH"] = 1] = "RESIZE_MODE_FIXED_WIDTH";
    /**
     * The height is fixed and the width is increased or decreased to obtain the desired aspect ratio.
     */
    ResizeMode[ResizeMode["RESIZE_MODE_FIXED_HEIGHT"] = 2] = "RESIZE_MODE_FIXED_HEIGHT";
    /**
     * The height and the width is increased or decreased to fit the size of the view.
     */
    ResizeMode[ResizeMode["RESIZE_MODE_FILL"] = 3] = "RESIZE_MODE_FILL";
    /**
     * Keeps the aspect ratio but takes up the view's size.
     */
    ResizeMode[ResizeMode["RESIZE_MODE_CENTER_CROP"] = 4] = "RESIZE_MODE_CENTER_CROP";
})(ResizeMode || (ResizeMode = {}));
exports.ResizeMode = ResizeMode;
VideoPlayer.defaultProps = {
    play: true,
    controls: false,
    controlsTimeout: 5000,
    showBuffering: true,
    repeatMode: RepeatMode.REPEAT_MODE_OFF,
    onBack: () => { },
    onFullScreen: () => { },
};
exports.default = VideoPlayer;
